@@ -21,6 +21,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "mtproto/mtp_instance.h"
 #include "mtproto/mtproto_config.h"
 #include "mtproto/mtproto_dc_options.h"
+#include "chat_helpers/stickers_dice_pack.h"
 #include "data/business/data_shortcut_messages.h"
 #include "data/components/credits.h"
 #include "data/components/gift_auctions.h"
@@ -137,100 +138,6 @@ bool HasForceLogoutNotification(const MTPUpdates &updates) {
 	return false;
 }
 
-bool ForwardedInfoDataLoaded(
-		not_null<Main::Session*> session,
-		const MTPMessageFwdHeader &header) {
-	return header.match([&](const MTPDmessageFwdHeader &data) {
-		if (const auto fromId = data.vfrom_id()) {
-			// Fully loaded is required in this case.
-			if (!session->data().peerLoaded(peerFromMTP(*fromId))) {
-				return false;
-			}
-		}
-		return true;
-	});
-}
-
-bool MentionUsersLoaded(
-		not_null<Main::Session*> session,
-		const MTPVector<MTPMessageEntity> &entities) {
-	for (const auto &entity : entities.v) {
-		auto type = entity.type();
-		if (type == mtpc_messageEntityMentionName) {
-			if (!session->data().userLoaded(entity.c_messageEntityMentionName().vuser_id())) {
-				return false;
-			}
-		} else if (type == mtpc_inputMessageEntityMentionName) {
-			auto &inputUser = entity.c_inputMessageEntityMentionName().vuser_id();
-			if (inputUser.type() == mtpc_inputUser) {
-				if (!session->data().userLoaded(inputUser.c_inputUser().vuser_id())) {
-					return false;
-				}
-			}
-		}
-	}
-	return true;
-}
-
-DataIsLoadedResult AllDataLoadedForMessage(
-		not_null<Main::Session*> session,
-		const MTPMessage &message) {
-	return message.match([&](const MTPDmessage &message) {
-		if (const auto fromId = message.vfrom_id()) {
-			if (!message.is_post()
-				&& !session->data().peerLoaded(peerFromMTP(*fromId))) {
-				return DataIsLoadedResult::FromNotLoaded;
-			}
-		}
-		if (const auto viaBotId = message.vvia_bot_id()) {
-			if (!session->data().userLoaded(*viaBotId)) {
-				return DataIsLoadedResult::NotLoaded;
-			}
-		}
-		if (const auto fwd = message.vfwd_from()) {
-			if (!ForwardedInfoDataLoaded(session, *fwd)) {
-				return DataIsLoadedResult::NotLoaded;
-			}
-		}
-		if (const auto entities = message.ventities()) {
-			if (!MentionUsersLoaded(session, *entities)) {
-				return DataIsLoadedResult::MentionNotLoaded;
-			}
-		}
-		return DataIsLoadedResult::Ok;
-	}, [&](const MTPDmessageService &message) {
-		if (const auto fromId = message.vfrom_id()) {
-			if (!message.is_post()
-				&& !session->data().peerLoaded(peerFromMTP(*fromId))) {
-				return DataIsLoadedResult::FromNotLoaded;
-			}
-		}
-		return message.vaction().match(
-		[&](const MTPDmessageActionChatAddUser &action) {
-			for (const auto &userId : action.vusers().v) {
-				if (!session->data().userLoaded(userId)) {
-					return DataIsLoadedResult::NotLoaded;
-				}
-			}
-			return DataIsLoadedResult::Ok;
-		}, [&](const MTPDmessageActionChatJoinedByLink &action) {
-			if (!session->data().userLoaded(action.vinviter_id())) {
-				return DataIsLoadedResult::NotLoaded;
-			}
-			return DataIsLoadedResult::Ok;
-		}, [&](const MTPDmessageActionChatDeleteUser &action) {
-			if (!session->data().userLoaded(action.vuser_id())) {
-				return DataIsLoadedResult::NotLoaded;
-			}
-			return DataIsLoadedResult::Ok;
-		}, [](const auto &) {
-			return DataIsLoadedResult::Ok;
-		});
-	}, [](const MTPDmessageEmpty &message) {
-		return DataIsLoadedResult::Ok;
-	});
-}
-
 } // namespace
 
 Updates::Updates(not_null<Main::Session*> session)
@@ -246,12 +153,12 @@ Updates::Updates(not_null<Main::Session*> session)
 	_ptsWaiter.setRequesting(true);
 
 	session->account().mtpUpdates(
-	) | rpl::start_with_next([=](const MTPUpdates &updates) {
+	) | rpl::on_next([=](const MTPUpdates &updates) {
 		mtpUpdateReceived(updates);
 	}, _lifetime);
 
 	session->account().mtpNewSessionCreated(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		mtpNewSessionCreated();
 	}, _lifetime);
 
@@ -265,7 +172,7 @@ Updates::Updates(not_null<Main::Session*> session)
 		Data::PeerUpdate::Flag::FullInfo
 	) | rpl::filter([](const Data::PeerUpdate &update) {
 		return update.peer->isChat() || update.peer->isMegagroup();
-	}) | rpl::start_with_next([=](const Data::PeerUpdate &update) {
+	}) | rpl::on_next([=](const Data::PeerUpdate &update) {
 		const auto peer = update.peer;
 		if (const auto list = _pendingSpeakingCallParticipants.take(peer)) {
 			if (const auto call = peer->groupCall()) {
@@ -747,7 +654,7 @@ void Updates::getChannelDifference(
 	}
 	api().request(MTPupdates_GetChannelDifference(
 		MTP_flags(flags),
-		channel->inputChannel,
+		channel->inputChannel(),
 		filter,
 		MTP_int(channel->pts()),
 		MTP_int(kChannelGetDifferenceLimit)
@@ -766,7 +673,7 @@ void Updates::addActiveChat(rpl::producer<PeerData*> chat) {
 	const auto key = _activeChats.empty() ? 0 : _activeChats.back().first + 1;
 	std::move(
 		chat
-	) | rpl::start_with_next_done([=](PeerData *peer) {
+	) | rpl::on_next_done([=](PeerData *peer) {
 		auto &active = _activeChats[key];
 		const auto was = active.peer;
 		if (was != peer) {
@@ -826,7 +733,7 @@ void Updates::channelRangeDifferenceSend(
 			MTP_int(range.till - 1))));
 	const auto requestId = api().request(MTPupdates_GetChannelDifference(
 		MTP_flags(MTPupdates_GetChannelDifference::Flag::f_force),
-		channel->inputChannel,
+		channel->inputChannel(),
 		filter,
 		MTP_int(pts),
 		MTP_int(limit)
@@ -1238,7 +1145,8 @@ void Updates::applyUpdatesNoPtsCheck(const MTPUpdates &updates) {
 				MTPint(), // report_delivery_until_date
 				MTPlong(), // paid_message_stars
 				MTPSuggestedPost(),
-				MTPint()), // schedule_repeat_period
+				MTPint(), // schedule_repeat_period
+				MTPstring()), // summary_from_language
 			MessageFlags(),
 			NewMessageType::Unread);
 	} break;
@@ -1279,7 +1187,8 @@ void Updates::applyUpdatesNoPtsCheck(const MTPUpdates &updates) {
 				MTPint(), // report_delivery_until_date
 				MTPlong(), // paid_message_stars
 				MTPSuggestedPost(),
-				MTPint()), // schedule_repeat_period
+				MTPint(), // schedule_repeat_period
+				MTPstring()), // summary_from_language
 			MessageFlags(),
 			NewMessageType::Unread);
 	} break;
@@ -1513,18 +1422,13 @@ void Updates::applyUpdates(
 
 	case mtpc_updateShortMessage: {
 		auto &d = updates.c_updateShortMessage();
-		const auto viaBotId = d.vvia_bot_id();
-		const auto entities = d.ventities();
-		const auto fwd = d.vfwd_from();
-		if (!session().data().userLoaded(d.vuser_id())
-			|| (viaBotId && !session().data().userLoaded(*viaBotId))
-			|| (entities && !MentionUsersLoaded(&session(), *entities))
-			|| (fwd && !ForwardedInfoDataLoaded(&session(), *fwd))) {
+		if (!session().data().userLoaded(d.vuser_id())) {
 			MTP_LOG(0, ("getDifference "
 				"{ good - getting user for updateShortMessage }%1"
-				).arg(_session->mtp().isTestMode() ? " TESTMODE" : ""));
+			).arg(_session->mtp().isTestMode() ? " TESTMODE" : ""));
 			return getDifference();
 		}
+		_session->data().fillMessagePeers(d);
 		if (updateAndApply(d.vpts().v, d.vpts_count().v, updates)) {
 			// Update date as well.
 			setState(0, d.vdate().v, _updatesQts, _updatesSeq);
@@ -1533,24 +1437,14 @@ void Updates::applyUpdates(
 
 	case mtpc_updateShortChatMessage: {
 		auto &d = updates.c_updateShortChatMessage();
-		const auto noFrom = !session().data().userLoaded(d.vfrom_id());
 		const auto chat = session().data().chatLoaded(d.vchat_id());
-		const auto viaBotId = d.vvia_bot_id();
-		const auto entities = d.ventities();
-		const auto fwd = d.vfwd_from();
-		if (!chat
-			|| noFrom
-			|| (viaBotId && !session().data().userLoaded(*viaBotId))
-			|| (entities && !MentionUsersLoaded(&session(), *entities))
-			|| (fwd && !ForwardedInfoDataLoaded(&session(), *fwd))) {
+		if (!chat) {
 			MTP_LOG(0, ("getDifference "
-				"{ good - getting user for updateShortChatMessage }%1"
-				).arg(_session->mtp().isTestMode() ? " TESTMODE" : ""));
-			if (chat && noFrom) {
-				session().api().requestFullPeer(chat);
-			}
+				"{ good - getting chat for updateShortChatMessage }%1"
+			).arg(_session->mtp().isTestMode() ? " TESTMODE" : ""));
 			return getDifference();
 		}
+		_session->data().fillMessagePeers(d);
 		if (updateAndApply(d.vpts().v, d.vpts_count().v, updates)) {
 			// Update date as well.
 			setState(0, d.vdate().v, _updatesQts, _updatesSeq);
@@ -1580,13 +1474,7 @@ void Updates::applyUpdates(
 			const auto wasAlready = (lookupMessage() != nullptr);
 			feedUpdate(MTP_updateMessageID(d.vid(), MTP_long(randomId))); // ignore real date
 			if (const auto item = lookupMessage()) {
-				const auto list = d.ventities();
-				if (list && !MentionUsersLoaded(&session(), *list)) {
-					session().api().requestMessageData(
-						item->history()->peer,
-						item->id,
-						nullptr);
-				}
+				_session->data().fillMessagePeers(item->fullId(), d);
 				item->applySentMessage(sent.text, d, wasAlready);
 			}
 		}
@@ -1613,25 +1501,22 @@ void Updates::feedUpdate(const MTPUpdate &update) {
 	// New messages.
 	case mtpc_updateNewMessage: {
 		auto &d = update.c_updateNewMessage();
-
-		const auto isDataLoaded = AllDataLoadedForMessage(&session(), d.vmessage());
-		if (!requestingDifference() && isDataLoaded != DataIsLoadedResult::Ok) {
-			MTP_LOG(0, ("getDifference "
-				"{ good - after not all data loaded in updateNewMessage }%1"
+		if (!requestingDifference()) {
+			const auto peerId = PeerFromMessage(d.vmessage());
+			const auto peer = session().data().peerLoaded(peerId);
+			if (peerId && !peer) {
+				MTP_LOG(0, ("getDifference "
+					"{ good - getting peer for updateNewMessage }%1"
 				).arg(_session->mtp().isTestMode() ? " TESTMODE" : ""));
-
-			// This can be if this update was created by grouping
-			// some short message update into an updates vector.
-			return getDifference();
+				return getDifference();
+			}
 		}
-
 		updateAndApply(d.vpts().v, d.vpts_count().v, update);
 	} break;
 
 	case mtpc_updateNewChannelMessage: {
 		auto &d = update.c_updateNewChannelMessage();
 		auto channel = session().data().channelLoaded(peerToChannel(PeerFromMessage(d.vmessage())));
-		const auto isDataLoaded = AllDataLoadedForMessage(&session(), d.vmessage());
 		{
 			// Todo delete.
 			const auto messageId = IdFromMessage(d.vmessage());
@@ -1643,22 +1528,10 @@ void Updates::feedUpdate(const MTPUpdate &update) {
 				}
 			}
 		}
-		if (!requestingDifference() && (!channel || isDataLoaded != DataIsLoadedResult::Ok)) {
+		if (!requestingDifference() && !channel) {
 			MTP_LOG(0, ("getDifference "
 				"{ good - after not all data loaded in updateNewChannelMessage }%1"
 				).arg(_session->mtp().isTestMode() ? " TESTMODE" : ""));
-
-			// Request last active supergroup participants if the 'from' user was not loaded yet.
-			// This will optimize similar getDifference() calls for almost all next messages.
-			if (isDataLoaded == DataIsLoadedResult::FromNotLoaded && channel && channel->isMegagroup()) {
-				if (channel->canViewMembers()
-					&& channel->mgInfo->lastParticipants.size() < _session->serverConfig().chatSizeMax
-					&& (channel->mgInfo->lastParticipants.empty()
-						|| channel->mgInfo->lastParticipants.size() < channel->membersCount())) {
-					session().api().chatParticipants().requestLast(channel);
-				}
-			}
-
 			if (!_byMinChannelTimer.isActive()) { // getDifference after timeout
 				_byMinChannelTimer.callOnce(PtsWaiter::kWaitForSkippedTimeout);
 			}
@@ -2807,6 +2680,11 @@ void Updates::feedUpdate(const MTPUpdate &update) {
 		const auto &data = update.c_updateStarGiftAuctionUserState();
 		_session->giftAuctions().apply(data);
 	} break;
+
+	case mtpc_updateEmojiGameInfo: {
+		const auto &data = update.c_updateEmojiGameInfo();
+		_session->diceStickersPacks().apply(data);
+	} break;
 	}
 }
 
