@@ -115,18 +115,18 @@ PeerShortInfoCover::PeerShortInfoCover(
 
 	std::move(
 		userpic
-	) | rpl::start_with_next([=](PeerShortInfoUserpic &&value) {
+	) | rpl::on_next([=](PeerShortInfoUserpic &&value) {
 		applyUserpic(std::move(value));
 		applyAdditionalStatus(value.additionalStatus);
 	}, lifetime());
 
 	style::PaletteChanged(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		refreshBarImages();
 	}, lifetime());
 
 	_widget->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = QPainter(_widget.get());
 		paint(p);
 	}, lifetime());
@@ -478,7 +478,7 @@ void PeerShortInfoCover::applyUserpic(PeerShortInfoUserpic &&value) {
 		_videoStartPosition = value.videoStartPosition;
 		_videoInstance->lockPlayer();
 		_videoInstance->player().updates(
-		) | rpl::start_with_next_error([=](Update &&update) {
+		) | rpl::on_next_error([=](Update &&update) {
 			handleStreamingUpdate(std::move(update));
 		}, [=](Error &&error) {
 			handleStreamingError(std::move(error));
@@ -685,7 +685,7 @@ PeerShortInfoBox::PeerShortInfoBox(
 	_rows->add(_cover.takeOwned());
 
 	_scroll->scrolls(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_cover.setScrollTop(_scroll->scrollTop());
 	}, _cover.lifetime());
 }
@@ -720,7 +720,7 @@ void PeerShortInfoBox::prepare() {
 
 	_topRoundBackground->resize(st::shortInfoWidth, st::boxRadius);
 	_topRoundBackground->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (const auto use = fillRoundedTopHeight()) {
 			const auto width = _topRoundBackground->width();
 			const auto top = _topRoundBackground->height() - use;
@@ -751,7 +751,7 @@ void PeerShortInfoBox::prepareRows() {
 			const style::FlatLabel &textSt) {
 		auto line = CreateTextWithLabel(
 			_rows,
-			rpl::duplicate(label) | Ui::Text::ToWithEntities(),
+			rpl::duplicate(label) | rpl::map(tr::marked),
 			rpl::duplicate(text),
 			_st.label,
 			textSt,
@@ -763,7 +763,7 @@ void PeerShortInfoBox::prepareRows() {
 		rpl::combine(
 			std::move(label),
 			std::move(text)
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			_rows->resizeToWidth(st::shortInfoWidth);
 		}, _rows->lifetime());
 
@@ -801,7 +801,7 @@ void PeerShortInfoBox::prepareRows() {
 		tr::lng_context_copy_link(tr::now));
 	addInfoOneLine(
 		tr::lng_info_mobile_label(),
-		phoneValue() | Ui::Text::ToWithEntities(),
+		phoneValue() | rpl::map(tr::marked),
 		tr::lng_profile_copy_phone(tr::now));
 	auto label = _fields.current().isBio
 		? tr::lng_info_bio_label()
@@ -809,12 +809,16 @@ void PeerShortInfoBox::prepareRows() {
 	addInfoLine(std::move(label), aboutValue(), _st.labeled);
 	addInfoOneLine(
 		tr::lng_info_username_label(),
-		usernameValue() | Ui::Text::ToWithEntities(),
+		usernameValue() | rpl::map(tr::marked),
 		tr::lng_context_copy_mention(tr::now));
 	addInfoOneLine(
 		birthdayLabel(),
-		birthdayValue() | Ui::Text::ToWithEntities(),
+		birthdayValue() | rpl::map(tr::marked),
 		tr::lng_mediaview_copy(tr::now));
+	addInfoLine(
+		tr::lng_info_notes_label(),
+		noteValue(),
+		_st.labeled);
 }
 
 void PeerShortInfoBox::resizeEvent(QResizeEvent *e) {
@@ -877,14 +881,14 @@ rpl::producer<QString> PeerShortInfoBox::nameValue() const {
 rpl::producer<TextWithEntities> PeerShortInfoBox::channelValue() const {
 	return _fields.value(
 	) | rpl::map([](const PeerShortInfoFields &fields) {
-		return Ui::Text::Link(fields.channelName, fields.channelLink);
+		return tr::link(fields.channelName, fields.channelLink);
 	}) | rpl::distinct_until_changed();
 }
 
 rpl::producer<TextWithEntities> PeerShortInfoBox::linkValue() const {
 	return _fields.value(
 	) | rpl::map([](const PeerShortInfoFields &fields) {
-		return Ui::Text::Link(fields.link, fields.link);
+		return tr::link(fields.link, fields.link);
 	}) | rpl::distinct_until_changed();
 }
 
@@ -921,3 +925,9 @@ rpl::producer<TextWithEntities> PeerShortInfoBox::aboutValue() const {
 		return fields.about;
 	}) | rpl::distinct_until_changed();
 }
+
+rpl::producer<TextWithEntities> PeerShortInfoBox::noteValue() const {
+	return _fields.value() | rpl::map([](const PeerShortInfoFields &fields) {
+		return fields.note;
+	}) | rpl::distinct_until_changed();
+}
