@@ -58,8 +58,8 @@ void Setup(
 		MTP_flags(Flag::f_bot
 			| Flag::f_enabled
 			| (description.isEmpty() ? Flag() : Flag::f_custom_description)),
-		bot->inputUser,
-		peer->input,
+		bot->inputUser(),
+		peer->input(),
 		MTP_string(description)
 	)).done([=] {
 		done(QString());
@@ -74,8 +74,8 @@ void Remove(
 		Fn<void(QString)> done) {
 	bot->session().api().request(MTPbots_SetCustomVerification(
 		MTP_flags(MTPbots_SetCustomVerification::Flag::f_bot),
-		bot->inputUser,
-		peer->input,
+		bot->inputUser(),
+		peer->input(),
 		MTPstring()
 	)).done([=] {
 		done(QString());
