@@ -89,6 +89,10 @@ struct StoriesInfo {
 	int count = 0;
 };
 
+struct ProfileMusicInfo {
+	int count = 0;
+};
+
 struct FileLocation {
 	int dcId = 0;
 	MTPInputFileLocation data;
@@ -686,6 +690,13 @@ struct ActionStarGift {
 	std::vector<TextPart> text;
 	bool anonymous = false;
 	bool limited = false;
+
+	CreditsAmount offerPrice;
+	TimeId offerExpireAt = 0;
+	bool offer = false;
+	bool offerAccepted = false;
+	bool offerDeclined = false;
+	bool offerExpired = false;
 };
 
 struct ActionPaidMessagesRefunded {
@@ -929,6 +940,11 @@ StoriesSlice ParseStoriesSlice(
 	const MTPVector<MTPStoryItem> &data,
 	int baseIndex);
 
+struct ProfileMusicSlice {
+	std::vector<Message> list;
+	int skipped = 0;
+};
+
 Message ParseMessage(
 	ParseMediaContext &context,
 	const MTPMessage &data,
