@@ -20,6 +20,10 @@ class NumberInput;
 class InputField;
 } // namespace Ui
 
+namespace Ui::Text {
+class CustomEmojiHelper;
+} // namespace Ui::Text
+
 namespace Main {
 class Session;
 } // namespace Main
@@ -34,6 +38,7 @@ enum class SuggestMode {
 	New,
 	Change,
 	Publish,
+	Gift,
 };
 
 struct SuggestTimeBoxArgs {
@@ -46,21 +51,6 @@ void ChooseSuggestTimeBox(
 	not_null<Ui::GenericBox*> box,
 	SuggestTimeBoxArgs &&args);
 
-struct StarsInputFieldArgs {
-	std::optional<int64> value;
-	int64 max = 0;
-};
-[[nodiscard]] not_null<Ui::NumberInput*> AddStarsInputField(
-	not_null<Ui::VerticalLayout*> container,
-	StarsInputFieldArgs &&args);
-
-struct TonInputFieldArgs {
-	int64 value = 0;
-};
-[[nodiscard]] not_null<Ui::InputField*> AddTonInputField(
-	not_null<Ui::VerticalLayout*> container,
-	TonInputFieldArgs &&args);
-
 struct StarsTonPriceInput {
 	Fn<void()> focusCallback;
 	Fn<std::optional<CreditsAmount>()> computeResult;
@@ -77,6 +67,8 @@ struct StarsTonPriceArgs {
 	int starsMax = 0;
 	int64 nanoTonMin = 0;
 	int64 nanoTonMax = 0;
+	bool allowEmpty = false;
+	Fn<void(CreditsAmount)> errorHook;
 	rpl::producer<TextWithEntities> starsAbout;
 	rpl::producer<TextWithEntities> tonAbout;
 };
@@ -88,9 +80,10 @@ struct StarsTonPriceArgs {
 struct SuggestPriceBoxArgs {
 	not_null<PeerData*> peer;
 	bool updating = false;
-	Fn<void(SuggestPostOptions)> done;
-	SuggestPostOptions value;
+	Fn<void(SuggestOptions)> done;
+	SuggestOptions value;
 	SuggestMode mode = SuggestMode::New;
+	QString giftName;
 };
 void ChooseSuggestPriceBox(
 	not_null<Ui::GenericBox*> box,
@@ -107,19 +100,14 @@ void ChooseSuggestPriceBox(
 	not_null<Main::Session*> session,
 	CreditsAmount price);
 
-void InsufficientTonBox(
-	not_null<Ui::GenericBox*> box,
-	not_null<PeerData*> peer,
-	CreditsAmount required);
-
-class SuggestOptions final {
+class SuggestOptionsBar final {
 public:
-	SuggestOptions(
+	SuggestOptionsBar(
 		std::shared_ptr<ChatHelpers::Show> show,
 		not_null<PeerData*> peer,
-		SuggestPostOptions values,
+		SuggestOptions values,
 		SuggestMode mode);
-	~SuggestOptions();
+	~SuggestOptionsBar();
 
 	void paintBar(QPainter &p, int x, int y, int outerWidth);
 	void edit();
@@ -127,7 +115,7 @@ public:
 	void paintIcon(QPainter &p, int x, int y, int outerWidth);
 	void paintLines(QPainter &p, int x, int y, int outerWidth);
 
-	[[nodiscard]] SuggestPostOptions values() const;
+	[[nodiscard]] SuggestOptions values() const;
 
 	[[nodiscard]] rpl::producer<> updates() const;
 
@@ -136,7 +124,8 @@ public:
 private:
 	void updateTexts();
 
-	[[nodiscard]] TextWithEntities composeText() const;
+	[[nodiscard]] TextWithEntities composeText(
+		Ui::Text::CustomEmojiHelper &helper) const;
 
 	const std::shared_ptr<ChatHelpers::Show> _show;
 	const not_null<PeerData*> _peer;
@@ -145,7 +134,7 @@ private:
 	Ui::Text::String _title;
 	Ui::Text::String _text;
 
-	SuggestPostOptions _values;
+	SuggestOptions _values;
 	rpl::event_stream<> _updates;
 
 	rpl::lifetime _lifetime;
