@@ -14,6 +14,11 @@ namespace Ui {
 struct ColorIndicesCompressed;
 } // namespace Ui
 
+namespace Calls::Group::Ui {
+using namespace ::Ui;
+struct StarsColoring;
+} // namespace Calls::Group::Ui
+
 namespace Main {
 
 class Account;
@@ -42,6 +47,8 @@ public:
 			return getStringMap(key, std::move(fallback));
 		} else if constexpr (std::is_same_v<Type, std::vector<int>>) {
 			return getIntArray(key, std::move(fallback));
+		} else if constexpr (std::is_same_v<Type, std::vector<int64>>) {
+			return getInt64Array(key, std::move(fallback));
 		} else if constexpr (std::is_same_v<Type, bool>) {
 			return getBool(key, fallback);
 		}
@@ -72,6 +79,8 @@ public:
 	[[nodiscard]] int starsWithdrawMax() const;
 	[[nodiscard]] float64 starsWithdrawRate() const;
 	[[nodiscard]] float64 currencyWithdrawRate() const;
+	[[nodiscard]] float64 starsSellRate() const;
+	[[nodiscard]] float64 currencySellRate() const;
 	[[nodiscard]] bool paidMessagesAvailable() const;
 	[[nodiscard]] int paidMessageStarsMax() const;
 	[[nodiscard]] int paidMessageCommission() const;
@@ -118,6 +127,16 @@ public:
 	[[nodiscard]] int groupCallMessageLengthLimit() const;
 	[[nodiscard]] TimeId groupCallMessageTTL() const;
 
+	[[nodiscard]] int passkeysAccountPasskeysMax() const;
+	[[nodiscard]] bool settingsDisplayPasskeys() const;
+
+	[[nodiscard]] int64 stakeDiceNanoTonMin() const;
+	[[nodiscard]] int64 stakeDiceNanoTonMax() const;
+	[[nodiscard]] std::vector<int64> stakeDiceNanoTonSuggested() const;
+
+	using StarsColoring = Calls::Group::Ui::StarsColoring;
+	[[nodiscard]] std::vector<StarsColoring> groupCallColorings() const;
+
 	void refresh(bool force = false);
 
 private:
@@ -146,6 +165,9 @@ private:
 	[[nodiscard]] std::vector<int> getIntArray(
 		const QString &key,
 		std::vector<int> &&fallback) const;
+	[[nodiscard]] std::vector<int64> getInt64Array(
+		const QString &key,
+		std::vector<int64> &&fallback) const;
 
 	void updateIgnoredRestrictionReasons(std::vector<QString> was);
 
@@ -162,6 +184,8 @@ private:
 
 	std::vector<QString> _startRefPrefixes;
 
+	mutable std::vector<StarsColoring> _groupCallColorings;
+
 	crl::time _lastFrozenRefresh = 0;
 	rpl::lifetime _frozenTrackLifetime;
 
