@@ -33,6 +33,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/components/factchecks.h"
 #include "data/components/gift_auctions.h"
 #include "data/components/location_pickers.h"
+#include "data/components/passkeys.h"
 #include "data/components/promo_suggestions.h"
 #include "data/components/recent_peers.h"
 #include "data/components/recent_shared_media_gifts.h"
@@ -136,7 +137,7 @@ Session::Session(
 			_promoSuggestions->setupEmailStateValue(
 			) | rpl::filter([](Data::SetupEmailState s) {
 				return s == Data::SetupEmailState::None;
-			}) | rpl::take(1) | rpl::start_with_next(crl::guard(this, [=] {
+			}) | rpl::take(1) | rpl::on_next(crl::guard(this, [=] {
 				Core::App().unlockSetupEmail();
 				_settings->setSetupEmailState(State::None);
 				saveSettingsDelayed(200);
@@ -155,6 +156,7 @@ Session::Session(
 		}
 	}
 }))
+, _passkeys(std::make_unique<Data::Passkeys>(this))
 , _cachedReactionIconFactory(std::make_unique<ReactionIconFactory>())
 , _supportHelper(Support::Helper::Create(this))
 , _fastButtonsBots(std::make_unique<Support::FastButtonsBots>(this))
@@ -171,7 +173,7 @@ Session::Session(
 	changes().peerFlagsValue(
 		_user,
 		Data::PeerUpdate::Flag::Photo
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto view = Ui::PeerUserpicView{ .cloud = _selfUserpicView };
 		[[maybe_unused]] const auto image = _user->userpicCloudImage(view);
 		_selfUserpicView = view.cloud;
@@ -186,7 +188,7 @@ Session::Session(
 			| Flag::Photo
 			| Flag::About
 			| Flag::PhoneNumber
-		) | rpl::start_with_next([=](const Data::PeerUpdate &update) {
+		) | rpl::on_next([=](const Data::PeerUpdate &update) {
 			local().writeSelf();
 
 			if (update.flags & Flag::PhoneNumber) {
@@ -236,7 +238,7 @@ Session::Session(
 	Core::App().downloadManager().trackSession(this);
 
 	appConfig().value(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		appConfigRefreshed();
 	}, _lifetime);
 }
