@@ -26,6 +26,8 @@ struct CreditTopupOption;
 struct SavedStarGift;
 class SavedStarGiftId;
 struct StarGift;
+struct UniqueGift;
+struct GiftUpgradeSpinner;
 } // namespace Data
 
 namespace HistoryView {
@@ -103,6 +105,7 @@ struct GiftWearBoxStyleOverride {
 	const style::FlatLabel *title = nullptr;
 	const style::FlatLabel *subtitle = nullptr;
 	const style::icon *radiantIcon = nullptr;
+	const style::icon *profileIcon = nullptr;
 	const style::icon *proofIcon = nullptr;
 	const style::FlatLabel *infoTitle = nullptr;
 	const style::FlatLabel *infoAbout = nullptr;
@@ -127,17 +130,34 @@ struct CreditsEntryBoxStyleOverrides {
 	const style::icon *hide = nullptr;
 	const style::icon *pin = nullptr;
 	const style::icon *unpin = nullptr;
+	const style::icon *offer = nullptr;
 	std::shared_ptr<ShareBoxStyleOverrides> shareBox;
 	std::shared_ptr<GiftWearBoxStyleOverride> giftWearBox;
 };
 [[nodiscard]] CreditsEntryBoxStyleOverrides DarkCreditsEntryBoxStyle();
 
+[[nodiscard]] rpl::producer<CreditsAmount> UniqueGiftResalePrice(
+	std::shared_ptr<Data::UniqueGift> unique,
+	bool forceTon = false);
+[[nodiscard]] bool UniqueGiftCanRemoveDetails(
+	const Data::CreditsHistoryEntry &entry);
+[[nodiscard]] Fn<void(Fn<void()> removed)> UniqueGiftRemoveDetailsHandler(
+	std::shared_ptr<ChatHelpers::Show> show,
+	const Data::CreditsHistoryEntry &entry);
+
 void GenericCreditsEntryBox(
 	not_null<Ui::GenericBox*> box,
 	std::shared_ptr<ChatHelpers::Show> show,
 	const Data::CreditsHistoryEntry &e,
 	const Data::SubscriptionEntry &s,
 	CreditsEntryBoxStyleOverrides st = {});
+void GenericCreditsEntryBody(
+	not_null<Ui::GenericBox*> box,
+	std::shared_ptr<ChatHelpers::Show> show,
+	const Data::CreditsHistoryEntry &e,
+	const Data::SubscriptionEntry &s,
+	std::shared_ptr<Data::GiftUpgradeSpinner> upgradeSpinner,
+	CreditsEntryBoxStyleOverrides st = {});
 void UniqueGiftValueBox(
 	not_null<Ui::GenericBox*> box,
 	std::shared_ptr<ChatHelpers::Show> show,
@@ -252,6 +272,8 @@ struct SmallBalanceForMessage {
 struct SmallBalanceForSuggest {
 	PeerId recipientId;
 };
+struct SmallBalanceForOffer {
+};
 struct SmallBalanceForSearch {
 };
 struct SmallBalanceSource : std::variant<
@@ -263,6 +285,7 @@ struct SmallBalanceSource : std::variant<
 	SmallBalanceStarGift,
 	SmallBalanceForMessage,
 	SmallBalanceForSuggest,
+	SmallBalanceForOffer,
 	SmallBalanceForSearch> {
 	using variant::variant;
 };
@@ -294,4 +317,9 @@ void AddMiniStars(
 	int boxWidth,
 	float64 heightRatio);
 
+void AddUniqueCloseMoreButton(
+	not_null<Ui::GenericBox*> box,
+	Settings::CreditsEntryBoxStyleOverrides st,
+	Fn<void(not_null<Ui::PopupMenu*>)> fillMenu = nullptr);
+
 } // namespace Settings
