@@ -206,7 +206,8 @@ AdminLog::OwnedItem GenerateForwardedItem(
 		MTPint(), // report_delivery_until_date
 		MTPlong(), // paid_message_stars
 		MTPSuggestedPost(),
-		MTPint() // schedule_repeat_period
+		MTPint(), // schedule_repeat_period
+		MTPstring() // summary_from_language
 	).match([&](const MTPDmessage &data) {
 		return history->makeMessage(
 			history->nextNonHistoryEntryId(),
@@ -1112,6 +1113,7 @@ object_ptr<Ui::RpWidget> ForwardsPrivacyController::setupAboveWidget(
 			_chatStyle.get(),
 			widget->rect(),
 			widget->rect(),
+			widget->rect(),
 			controller->isGifPausedAtLeastFor(
 				Window::GifPauseReason::Layer));
 		p.translate(padding / 2, padding + view->marginBottom());
