@@ -115,7 +115,7 @@ void PeerMenuCreatePoll(
 	not_null<Window::SessionController*> controller,
 	not_null<PeerData*> peer,
 	FullReplyTo replyTo = FullReplyTo(),
-	SuggestPostOptions suggest = SuggestPostOptions(),
+	SuggestOptions suggest = SuggestOptions(),
 	PollData::Flags chosen = PollData::Flags(),
 	PollData::Flags disabled = PollData::Flags(),
 	Api::SendType sendType = Api::SendType::Normal,
@@ -130,7 +130,7 @@ void PeerMenuCreateTodoList(
 	not_null<Window::SessionController*> controller,
 	not_null<PeerData*> peer,
 	FullReplyTo replyTo = FullReplyTo(),
-	SuggestPostOptions suggest = SuggestPostOptions(),
+	SuggestOptions suggest = SuggestOptions(),
 	Api::SendType sendType = Api::SendType::Normal,
 	SendMenu::Details sendMenuDetails = SendMenu::Details());
 void PeerMenuEditTodoList(
